@@ -41,5 +41,4 @@ def configure(tenant: str, token: str):
     """Configure sifflet variables"""
     service = ConfigureService()
     logger.debug("start service")
-    sifflet_config = service.configure(tenant, token)
-    service.show_configuration(sifflet_config)
+    service.configure(tenant, token)
