@@ -7,6 +7,7 @@ from rich import markup
 from rich.console import Console
 from rich.table import Table
 
+from client.model.rule_catalog_asset_dto import RuleCatalogAssetDto
 from client.model.rule_info_dto import RuleInfoDto
 from client.model.rule_run_dto import RuleRunDto
 from sifflet.constants import (
@@ -52,8 +53,8 @@ class RulesService:
                     "datasource_type": rule.get("datasource_type"),
                     "dataset_name": rule.get("dataset_name"),
                     "platform": rule.get("source_platform"),
-                    "last_run_status": self._format_status(rule.get("last_run_status", default="")["status"]),
-                    "last_run": str(datetime.fromtimestamp(rule.get("last_run", default=0) / 1000)),
+                    "last_run_status": self._get_last_run_status(rule),
+                    "last_run": self._get_last_run_timestamp(rule),
                 }
                 for rule in rules
             ]
@@ -82,6 +83,19 @@ class RulesService:
         else:
             logger.info("No rule found")
 
+    @staticmethod
+    def _get_last_run_timestamp(rule: RuleCatalogAssetDto) -> str:
+        if rule.get("last_run_status") and rule.get("last_run_status").timestamp:
+            return str(datetime.fromtimestamp(rule.get("last_run_status").timestamp / 1000))
+        else:
+            return ""
+
+    def _get_last_run_status(self, rule: RuleCatalogAssetDto) -> str:
+        if rule.get("last_run_status") and rule.get("last_run_status").status:
+            return self._format_status(rule.get("last_run_status").status)
+        else:
+            return ""
+
     @exception_handler
     def run_rules(self, rule_ids: List[str]) -> List[RuleRunDto]:
         rule_runs: List[RuleRunDto] = []
