@@ -1,8 +1,8 @@
 import requests
-from requests import Response
+from requests import Response, RequestException
 
+from client.api import access_token_api
 from sifflet.apis.base import BaseApi
-from sifflet.apis.client.api import access_token_api
 from sifflet.errors import exception_handler
 from sifflet.logger import logger
 
@@ -12,11 +12,13 @@ class ApiStatus(BaseApi):
         super().__init__(sifflet_config)
         self.api_instance = access_token_api.AccessTokenApi(self.api)
 
-    @exception_handler
     def fetch_health_tenant(self) -> bool:
         logger.debug(f"Check heath tenant = {self.host}")
         path: str = f"{self.host}/actuator/health"
-        response: Response = requests.get(path)
+        try:
+            response: Response = requests.get(path, timeout=60)
+        except RequestException:
+            return False
         return response.status_code == 200
 
     @exception_handler
