@@ -6,14 +6,14 @@ from rich.table import Table, Column
 from sifflet.logger import logger
 
 
-def show_table(table: List[dict], title: str = None):
+def show_table(table: List[dict], title: str = None) -> None:
     """Utility to display rich tables"""
 
     if table:
         header = list(table[0].keys())
 
         if "id" in header:
-            header = filter(lambda x: x != "id", header)
+            header = list(filter(lambda x: x != "id", header))
             table_formatted = Table(Column(header="id", no_wrap=True), *header)
         else:
             table_formatted = Table(*header)
